package DrawningObjects;

import Entities.*;
import MovementStrategy.*;

import java.awt.*;

public class DrawningElectricLocomotive {
    public EntityElectricLocomotive _entityElectricLocomotive;
    private DrawningWheels drawningWheels;
    private int _pictureWidth;
    private int _pictureHeight;
    private int _startPosX;
    private int _startPosY;
    private final int _locomotiveWidth = 120;
    private final int _locomotiveHeight = 70;

    public boolean Init(int speed, double weight, Color bodyColor, Color
            additionalColor, int countWheels, boolean horns, boolean battery, int width, int height) {
        if (width < _locomotiveWidth || height < _locomotiveHeight) {
            return false;
        }
        _pictureWidth = width;
        _pictureHeight = height;
        _entityElectricLocomotive = new EntityElectricLocomotive();
        _entityElectricLocomotive.Init(speed, weight, bodyColor, additionalColor,
                horns, battery);
        drawningWheels = new DrawningWheels();
        drawningWheels.setCount(countWheels);
        return true;
    }

    public void SetPosition(int x, int y) {
        x = Math.min(Math.max(0, x), _pictureWidth - _locomotiveWidth);
        y = Math.min(Math.max(0, y), _pictureHeight - _locomotiveHeight);
        _startPosX = x;
        _startPosY = y;
    }

    public void MoveTransport(DirectionType direction) {
        if (_entityElectricLocomotive == null) {
            return;
        }
        switch (direction) {
            //влево
            case DirectionType.Left:
                if (_startPosX - _entityElectricLocomotive.Step > 0) {
                    _startPosX -= (int) _entityElectricLocomotive.Step;
                }
                break;
            //вверх
            case DirectionType.Up:
                if (_startPosY - _entityElectricLocomotive.Step > 0) {
                    _startPosY -= (int) _entityElectricLocomotive.Step;
                }
                break;
            // вправо
            case DirectionType.Right:
                if (_startPosX + _locomotiveWidth + _entityElectricLocomotive.Step < _pictureWidth) {
                    _startPosX += (int) _entityElectricLocomotive.Step;
                }
                break;
            //вниз
            case DirectionType.Down:
                if (_startPosY + _locomotiveHeight + _entityElectricLocomotive.Step < _pictureHeight) {
                    _startPosY += (int) _entityElectricLocomotive.Step;
                }
                break;
        }
    }

    public void DrawTransport(Graphics g) {
        if (_entityElectricLocomotive == null) {
            return;
        }

        g.clearRect(0, 0, _pictureWidth, _pictureHeight);
        // корпус электровоза
        g.setColor(_entityElectricLocomotive.BodyColor);

        int[] posX = {
                _startPosX,
                _startPosX + 10,
                _startPosX + 120,
                _startPosX + 120,
                _startPosX
        };

        int[] posY = {
                _startPosY + 40,
                _startPosY + 20,
                _startPosY + 20,
                _startPosY + 60,
                _startPosY + 60
        };

        g.fillPolygon(posX, posY, 5);
        g.drawLine(_startPosX, _startPosY + 40,
                _startPosX + 120, _startPosY + 40);

        // окна
        g.setColor(Color.blue);
        g.fillRect(_startPosX + 12, _startPosY + 24, 30, 11);
        g.fillRect(_startPosX + 55, _startPosY + 24, 11, 11);
        g.fillRect(_startPosX + 75, _startPosY + 24, 11, 11);
        g.fillRect(_startPosX + 95, _startPosY + 24, 11, 11);

        // колёса
        drawningWheels.DrawWheels(g, _startPosX, _startPosY);

        // рога
        if (_entityElectricLocomotive.Horns) {
            g.setColor(Color.black);
            posX = new int[]{
                    _startPosX + 50,
                    _startPosX + 40,
                    _startPosX + 50,
                    _startPosX + 60
            };

            posY = new int[]{
                    _startPosY + 20,
                    _startPosY + 10,
                    _startPosY,
                    _startPosY + 10
            };
            g.drawPolygon(posX, posY, 4);
        }
        // отсек для батарей
        if (_entityElectricLocomotive.Battery) {
            g.setColor(_entityElectricLocomotive.AdditionalColor);
            g.fillRect(_startPosX + 80, _startPosY + 45, 35, 9);
        }
    }
    public void SetPictureSize(int width, int height)
    {
        _pictureWidth = width;
        _pictureHeight = height;
    }
}
